@@ -1,25 +1,26 @@
-# Copyright 2020-2021 SECO Mind S.r.l.
+# This file is part of Astarte.
+#
+# Copyright 2023 SECO Mind Srl
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
 #
-# http://www.apache.org/licenses/LICENSE-2.0
+#    http://www.apache.org/licenses/LICENSE-2.0
 #
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-
+#
+# SPDX-License-Identifier: Apache-2.0
 
 from datetime import datetime
 from os import path
 
 from cryptography import x509
-from cryptography.hazmat.backends import default_backend
-from cryptography.hazmat.primitives import hashes
-from cryptography.hazmat.primitives import serialization
+from cryptography.hazmat.primitives import hashes, serialization
 from cryptography.hazmat.primitives.asymmetric import ec
 from cryptography.x509.oid import NameOID
 
@@ -46,7 +47,7 @@ def generate_csr(realm: str, device_id: str, crypto_store_dir: str) -> bytes:
     # Do we need to generate a keypair?
     if not path.exists(path.join(crypto_store_dir, "device.key")):
         # Generate our key
-        key = ec.generate_private_key(curve=ec.SECP256R1(), backend=default_backend())
+        key = ec.generate_private_key(curve=ec.SECP256R1())
         # Write our key to disk for safe keeping
         with open(path.join(crypto_store_dir, "device.key"), "wb") as f:
             f.write(
@@ -59,23 +60,20 @@ def generate_csr(realm: str, device_id: str, crypto_store_dir: str) -> bytes:
     else:
         # Load the key
         with open(path.join(crypto_store_dir, "device.key"), "rb") as key_file:
-            key = serialization.load_pem_private_key(
-                key_file.read(), password=None, backend=default_backend()
-            )
+            key = serialization.load_pem_private_key(key_file.read(), password=None)
 
     csr = (
-        x509.CertificateSigningRequestBuilder()
-        .subject_name(
+        x509.CertificateSigningRequestBuilder().subject_name(
             x509.Name(
                 [
                     # Provide various details about who we are.
                     x509.NameAttribute(NameOID.ORGANIZATION_NAME, "Devices"),
                     x509.NameAttribute(NameOID.COMMON_NAME, f"{realm}/{device_id}"),
-                    # Sign the CSR with our private key.
                 ]
             )
         )
-        .sign(key, hashes.SHA256(), default_backend())
+        # Sign the CSR with our private key.
+        .sign(key, hashes.SHA256())
     )
 
     # Return the CSR
@@ -83,7 +81,18 @@ def generate_csr(realm: str, device_id: str, crypto_store_dir: str) -> bytes:
 
 
 def import_device_certificate(client_crt: str, crypto_store_dir: str) -> None:
-    certificate = x509.load_pem_x509_certificate(client_crt.encode("ascii"), default_backend())
+    """
+    Deserialize a client certificate and store the public information permanently in the file system
+
+    Parameters
+    ----------
+    client_crt: str
+        Serialized client certificate
+    crypto_store_dir: str
+        Directory where to store the public bytes of the certificate
+
+    """
+    certificate = x509.load_pem_x509_certificate(client_crt.encode("ascii"))
 
     # Store the certificate
     with open(path.join(crypto_store_dir, "device.crt"), "wb") as f:
@@ -133,7 +142,7 @@ def certificate_is_valid(crypto_store_dir: str) -> bool:
         data = file.read()
     if data:
         try:
-            certificate = x509.load_pem_x509_certificate(data.encode("ascii"), default_backend())
+            certificate = x509.load_pem_x509_certificate(data.encode("ascii"))
         except ValueError:
             return False
         return certificate.not_valid_before < datetime.utcnow() < certificate.not_valid_after
