@@ -1,23 +1,27 @@
-# Copyright 2020-2021 SECO Mind S.r.l.
+# This file is part of Astarte.
+#
+# Copyright 2023 SECO Mind Srl
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
 #
-# http://www.apache.org/licenses/LICENSE-2.0
+#    http://www.apache.org/licenses/LICENSE-2.0
 #
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+#
+# SPDX-License-Identifier: Apache-2.0
 
 from __future__ import annotations
 
 import datetime
 import http
 from base64 import urlsafe_b64encode
-from uuid import UUID, uuid5, uuid4
+from uuid import UUID, uuid4, uuid5
 
 import jwt
 import requests
@@ -35,21 +39,21 @@ def register_device_with_private_key(
     ignore_ssl_errors: bool,
 ) -> str:
     """
-    Registers a Device against an Astarte instance/realm with a Private Key
+    Registers a device against an Astarte instance/realm with a Private Key
 
-    Returns the Credentials secret for the Device
+    Returns the Credentials secret for the device
 
     Parameters
     ----------
     device_id : str
-        The Device ID to register.
+        The device ID to register.
     realm : str
-        The Realm in which to register the Device.
+        The Realm in which to register the device.
     private_key_file : str
         Path to the Private Key file for the Realm. It will be used to Authenticate against
         Pairing API.
     pairing_base_url : str
-        The Base URL of Pairing API of the Astarte Instance the Device will be registered in.
+        The Base URL of Pairing API of the Astarte Instance the device will be registered in.
     ignore_ssl_errors: str
         Set to True to ignore SSL errors
 
@@ -75,21 +79,21 @@ def register_device_with_jwt_token(
     ignore_ssl_errors: bool = False,
 ) -> str:
     """
-    Registers a Device against an Astarte instance/realm with a JWT Token
+    Registers a device against an Astarte instance/realm with a JWT Token
 
-    Returns the Credentials secret for the Device
+    Returns the Credentials secret for the device
 
     Parameters
     ----------
     device_id : str
-        The Device ID to register.
+        The device ID to register.
     realm : str
-        The Realm in which to register the Device.
+        The Realm in which to register the device.
     jwt_token : str
         A JWT Token to Authenticate against Pairing API. The token must have access to Pairing
         API and to the agent API paths.
     pairing_base_url : str
-        The Base URL of Pairing API of the Astarte Instance the Device will be registered in.
+        The Base URL of Pairing API of the Astarte Instance the device will be registered in.
     ignore_ssl_errors: bool
         Useful if you're registering a device into a test instance of Astarte with self-signed
         certificates. It is not recommended to leave this `true` in production.
@@ -123,7 +127,7 @@ def generate_device_id(namespace: UUID, unique_data: str) -> str:
     Returns
     -------
     str
-        the generated device Id, using the standard Astarte Device ID encoding (base64
+        the generated device Id, using the standard Astarte device ID encoding (base64
         urlencoding without padding).
 
     """
@@ -142,7 +146,7 @@ def generate_random_device_id() -> str:
     Returns
     -------
     str
-        the generated device Id, using the standard Astarte Device ID encoding (base64
+        the generated device Id, using the standard Astarte device ID encoding (base64
         urlencoding without padding).
 
     """
@@ -293,7 +297,7 @@ def __register_device(
     AuthorizationError
         If the authentication provided was not correct
     DeviceAlreadyRegisteredError
-        If the Device was already registered
+        If the device was already registered
     APIError
         If a generic Error was returned by the APIs
     """
@@ -333,17 +337,19 @@ def __register_device_headers_with_private_key(private_key_file) -> dict:
 
     Raises
     ------
-    TypeError
+    JWTGenerationError
         If there is an error generating the token from the certificate
     """
     headers = {}
     try:
-        headers[
-            "Authorization"
-        ] = f'Bearer {__generate_token(private_key_file, key_type="pairing")}'
+        headers["Authorization"] = (
+            f'Bearer {__generate_token(private_key_file, key_type="pairing")}'
+        )
         return headers
-    except Exception as exc:
-        raise TypeError("Supplied Realm Key could not be used to generate a valid Token.") from exc
+    except jwt.exceptions.PyJWTError as exc:
+        raise exceptions.JWTGenerationError("Error encoding or decoding the JWT token.") from exc
+    except IOError as exc:
+        raise exceptions.JWTGenerationError("Error opening the private key file.") from exc
 
 
 def __register_device_headers_with_jwt_token(jwt_token: str) -> dict:
